pub async fn connect_admin_client_async(
state: &AdminSessionState,
) -> Result<TrellisClient, TrellisAuthError>Expand description
Connect an authenticated admin client from the stored session state.
pub async fn connect_admin_client_async(
state: &AdminSessionState,
) -> Result<TrellisClient, TrellisAuthError>Connect an authenticated admin client from the stored session state.